Name: bob
Version: 2.4.27
Release: 1
License: Apache-2.0
Summary: Better Object Builder for IBM i
Url: https://github.com/IBM/ibmi-bob/

BuildRequires: make-gnu
BuildRequires: tar-gnu
BuildRequires: gzip
BuildRequires: bash >= 5.1-2
Requires: bash >= 5.1-2
Requires: coreutils-gnu >= 8.25-5
Requires: sed-gnu >= 4.4-1
Requires: grep-gnu >= 3.0-2
Requires: gawk >= 4.1.4-2
Requires: make-gnu >= 4.2-2
Requires: python39 >= 3.9.18
Requires: python39-ibm_db >= 2.0.5.12

Source0: https://github.com/IBM/ibmi-bob/archive/refs/tags/v%{version}.tar.gz

%description
Better Object Builder, or Bob, is a free and open source build system for the
IBM i platform that is used to build native "QSYS" objects.
Here's what makes Bob different.
- Speed. Bob only compiles objects that need recompiling, like from new or 
  changed source code.
- Reliability. Bob understands the relationships between your objects, so if an
  item changes, then it and everything depending on it will be rebuilt.
- Industry standard. Object dependencies are specified using standard makefile
  syntax, and the actual build engine is GNU Make -- exactly like tens of 
  thousands of Linux and Unix software projects.
- Flexibility. Most objects defined to Bob typically build using your default
  values. Have a program that requires a custom activation group or a data area
  that needs to be created with a certain value? No problem, overriding compile
  parameters is trivial, and writing custom recipes for special objects is very
  straightforward. If you can code it, you can build it.
- Ease of use. Invoking a build of an entire codebase is done with just a 
  single command.


%prep
%setup -n ibmi-bob-%{version}


%install
mkdir -p %{buildroot}%{_libdir}/bob
mkdir -p %{buildroot}%{_bindir}/
cp -r ./* %{buildroot}%{_libdir}/bob
ln -sf %{_libdir}/bob/bin/makei %{buildroot}%{_bindir}/makei
ln -sf %{_libdir}/bob/bin/crtfrmstmf %{buildroot}%{_bindir}/crtfrmstmf

%files
%defattr(-, qsys, *none)
%{_libdir}/bob
%{_bindir}/makei
%{_bindir}/crtfrmstmf

%changelog
* Fri Apr 12 2024 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.27
- Support .CMD for pseudo-source for command objects as well as .CMDSRC
- By requiring 3.9 versions of python and the db2 interface, avoid
  mismatched level errors.  Using generic python3 was too generic and
  allowed mismatches between db2 interface and base python
* Mon Jan 29 2024 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.26
- Add support for OPM CL
- Support variable replacement in setIBMiEnvCmd in iproj.json
- Fix reversing of libraries in preUsrlibl in iproj.json
- Respect single quotes on compile for objects using crtfrmstmf
- Fix remaining issues with TGTCCSID appearing blank
* Tue Jan 16 2024 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.25
- CRTCBLMOD does not support DEFINE() - removed it from flags
* Tue Jan 16 2024 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.24
- support importing the member text into %TEXT comments at the top of
  the source stream file using `cvtsrcpf` by
  Irfan Sharif <IrfanSharif@ibm.com>
- support using this member text at the top of the source stream file
  when compiling by Irfan Sharif <IrfanSharif@ibm.com>
- `cvtsrcpf` now fully supports lower case parameter
- add DBGVIEW to CRTBNDC
- Fix empty TGTCCSID parms causing compile failures and TGTCCSID
  not being read from `.ibmi.json`
- Standardize all bash script shebang lines by
  John Weirich weirich_j@hotmail.com
- Add support for DTAQ objects by
  John Weirich weirich_j@hotmail.com
* Mon Dec 18 2023 Irfan Sharif <IrfanSharif@ibm.com> - 2.4.23
- Fix cvtsrcpf failing to insert line when importing member
  text
* Wed Dec 13 2023 Irfan Sharif <IrfanSharif@ibm.com> - 2.4.22
- Fix launch.sh timestamp to include millisecond
  so Merlin v1 viewer can parse date properly
* Fri Nov 3 2023 Irfan Sharif <IrfanSharif@ibm.com> - 2.4.21
- Full support of ILE COBOL including embedded SQL
* Fri Oct 27 2023 Irfan Sharif <IrfanSharif@ibm.com> - 2.4.20
- Fixed build and compile failure when adding CREATE_TYPEDEF
  to Rules.mk
- SUBDIRS entry of Rules.mk can now be specified in any case
* Mon Sep 11 2023 Irfan Sharif <IrfanSharif@ibm.com> - 2.4.19
- Fixed regression in def_rules.mk regarding outputting unnecessary
  logs
* Fri Sep 8 2023 Irfan Sharif <IrfanSharif@ibm.com> - 2.4.18
- Fixed regression in launch.sh regarding timestamp
* Fri Sep 8 2023 Irfan Sharif <IrfanSharif@ibm.com> - 2.4.17
- logs separated into targetobject.log files and references in joblog.json.
  Updated joblog.json to include properties object, source, object and failed.
- Changed BNDDIRSRC file extension to BNDDIR.
- Drop %N which doesn't work on Windows without privileged authority
- Add iproj.json so IBMi-BOB is a project
- Minor document fixes
* Fri Jul 7 2023 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.16
- `makei cvtsrcpf -l` now supports optionally generating stream files
with lowercase fie names.
- Fixes https://github.com/IBM/ibmi-bob/issues/236 DTAARA now supported
* Fri Jun 30 2023 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.15
- `makei cvtsrcpf` now supports library and source physical file names
  specified in lower case.
- `makei cvtsrcpf` now support missing member types.  A stream file with
  no file extension is created.
* Fri Apr 28 2023 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.13
- All compiler parameters can be overwritten by environment variables
  by passing -e var=val on the makei command or by having a separate
  'export var=val' command.
- By setting the 'precmd' and 'postcmd' environment variables to a
  CL command, that CL command will be executed before or after the
  compile command.  Typically this is done using a
  'MYTARGET.PGM: private precmd = MYCUSTOMCL' rule in the Rules.mk
  This implements https://github.com/IBM/ibmi-bob/issues/208
- The overriding of OBJLIB and TGTCCSID using .ibmi.json in
  a subdirectory needed to be restored. Fixed through
  https://github.com/IBM/ibmi-bob/pull/229
* Thu Apr 27 2023 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.12
- Support rules with no dependencies, which is useful for custom recipes.
  Addresses https://github.com/IBM/ibmi-bob/issues/223
- Support the splitting of lines using escaped newlines as described by
  https://www.gnu.org/software/make/manual/make.html#Splitting-Lines
* Mon Apr 17 2023 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.11
- Fix SAVOBJ/RSTOBJ command for crtfrmstmf - failed when deleting files that
  depend on a PF. https://github.com/IBM/ibmi-bob/issues/215 and
  https://github.com/IBM/ibmi-bob/issues/207
- Fix that only last private compile parameter override processed from Rules.mk
  took effect.  Documented under https://github.com/IBM/ibmi-bob/issues/201.
- Support multiple variable assignment operators, fixing
  https://github.com/IBM/ibmi-bob/issues/194
* Mon Mar 6 2023 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.10
- Support CRTSQLCPPI and additional parameters for CMOD
- Support CVTCCSID and TGTCCSID for CCSID support of C and CPP
- Default record length for CRTFRMSTMF is now defaults 32000 except for MNU and
  PNLGRP whose record length is automatically set to max of 268.  Can be
  overridden via parameter to CRTFRMSTMF or RCDLEN variable.
- CRTCMD PGM are now explicitly qualified to the specified OBJLIB
* Thu Feb 9 2023 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.9
- Event file names for source compiled directly into programs was broken,
  causing errors not to be shown in tooling such as Merlin
* Wed Jan 25 2023 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.8
- fix 'makei init'
- support CRTCMD ALLOW()
- support CRTCPPMOD - C++ compiler uses PASE which means that we have to spawm a
  job and lose the joblog.json info
* Tue Jan 17 2023 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.7
- Improve project structure and automate release process.  See the documentation
  at https://ibm.github.io/ibmi-bob/#/contributing/getting-started for how to
  setup development and run linter and tests and also release using `nox`.
  Github actions are configured to be triggered when a tag of the vn.n.n-n is
  pushed to master to publish to the yum repository.
* Mon Nov 14 2022 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.6
- Update bob.spec
* Mon Nov 14 2022 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.5
- BINDDIR source now has the file extension BINDIRSRC to differentiate it from
  the target object type BINDDIR
- The ability to build a directory or file via the
  `makei compile -f <dir>:<file>` to be able to build any arbitrary list of
  files and directories
- The iproj.json has additional attributes for iasp and sql attributes like
  current schema, path and sql vs system naming. (These are not yet supported
  within BOB, but are present for future extensibility and other tooling that
  will support them.
- Note for CL Pseudo source, make sure that you delete the target object before
  creating a new version to ensure the timestamps are accurate and the make
  processing works correctly
* Tue Oct 18 2022 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.4
- evfevent files were missing filenames
- CCSID issues when downloading evfevent files
* Tue Oct 18 2022 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.3
- fix dates in bob.spec
* Fri Oct 14 2022 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.2
- lowercase file names and extensions supported
- support for lowercase filenames mapping to uppercase targets when compiling
- support of TGTCCSID specified by .ibmi.json for all source types
- support for INCDIR for all types including CLLE, CRTSQLxxxI, CRTRPGMOD
* Thu Sep 29 2022 Edmund Reinhardt <edmund.reinhard@ca.ibm.com> - 2.4.1
- Fix regression in building CMD, MENU and BNDDIR objects
* Mon Aug 22 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.4.0
- Use a larger margin for runsqlstmt
- Simplified Rules.mk syntax
- Allow creating target from the source with a different name
- Add indication for custom recipes
- Fix failed to add multiple preUsrLibl/postUsrLibl
- Fix not enabling the CompatibilityMode on IBM i 7.3
- Update code for IBM i documentation
- Set make path to QOpenSys
* Thu May 19 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.3.9
- Fix no authority to read QADBFDEP when getting PF dependencies
* Tue May 17 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.3.8
- Fix terminal color-support by Jesse Gorzinski
* Mon May 09 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.3.7
- Fix UTF-8 handling
* Mon May 09 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.3.6
- New documentation site is available at https://ibm.github.io/ibmi-bob/
- Do not generate .ibmi.json when invoking makei cvtsrcpf to avoid
  misleading as to when target CCSID is required
- Fix the encoding issue(#86) on machines without Utf-8 support
* Thu Apr 21 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.3.5
- Replace all the python3.9 shebang to python3.6
* Thu Apr 21 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.3.4
- Temporarily downgrade the Python version to 3.6 due to Ansible issues
- Simplify Makefiles
- Optimize outputs
- Wrap and expose crtsrcpf command in makei
- Fix wrong object mapping for sqltrg file type
- Fix not setting the curlib for RUNSQLSTM commands
* Wed Apr 13 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.3.3
- Fix the error when running makei build
* Thu Apr 07 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.3.2
- Update to 2.3.2
- Allow undefined values for includePath and postUsrLibl in
  iproj.json
- Use python39-ibm_db instead python3-ibm_db
- Fix missing execute permission on getJobLog
* Mon Apr 04 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.3.0
- Update to 2.3.0
- Upgrades to Python 3.9 since 3.6 is out of support
* Tue Mar 29 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.2.9
- Update to 2.2.9
- Rewrite CRTFRMSTMF using Python
- Expose CRTFRMSTMF as a CLI program
- Refactored makei interface
- Fix the issue that includePath is not respected by CRTBNDRPG
- Set the OBJLIB for RUNSQLSTM by temporarily changing the CURLIB
- Refactored code structure
- No longer expose launch program
* Thu Feb 10 2022 Tongkun Zhang <tongkun.zhang@ibm.com> - 2.2.8
- Update to 2.2.8
- Install CRTFRMSTMF by restoring from SAVF instead of compiling
- Suppress errors from jq
- Add include path and user libraries to VPATH
- Include more joblog information
- Set Bash 5.1-2 as the minimum
